@@ -1,7 +1,10 @@
 """Views of the ``aps_purchasing`` app."""
 from django.contrib.auth.decorators import login_required
+from django.contrib.messages import info, warning
 from django.core.urlresolvers import reverse
+from django.shortcuts import redirect
 from django.utils.decorators import method_decorator
+from django.utils.translation import ugettext_lazy as _
 from django.views.generic import CreateView, DetailView
 
 from aps_bom.models import BOM
@@ -22,6 +25,7 @@ class QuotationUploadView(CreateView):
             request, *args, **kwargs)
 
     def get_success_url(self):
+        info(self.request, _('Quotation successfully uploaded.'))
         return reverse('aps_purchasing_quotation_upload')
 
 
@@ -32,10 +36,22 @@ class ReportView(DetailView):
     @method_decorator(login_required)
     def dispatch(self, request, *args, **kwargs):
         self.object = None
-        try:
-            self.object = BOM.objects.get(pk=kwargs.get('pk'))
-        except BOM.DoesNotExist:
-            pass
+        part_number = self.request.GET.get('part_number', '')
+        if part_number:
+            try:
+                self.object = BOM.objects.get(ipn__code=part_number)
+            except BOM.DoesNotExist:
+                warning(request, _(
+                    'BOM with part number "{0} not found".'.format(
+                        part_number)))
+            else:
+                return redirect(reverse('aps_purchasing_report', kwargs={
+                    'pk': self.object.pk}))
+        else:
+            try:
+                self.object = BOM.objects.get(pk=kwargs.get('pk'))
+            except BOM.DoesNotExist:
+                pass
         return super(ReportView, self).dispatch(request, *args, **kwargs)
 
     def get_context_data(self, **kwargs):
